FL.objects.Options.Options
==========================

.. currentmodule:: FL.objects.Options

.. autoclass:: Options
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Options.Init
      ~Options.Load
      ~Options.Save
      ~Options.__init__
      ~Options.fake_load_regfile
      ~Options.fake_save_regfile
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Options.AutoAlignVector
      ~Options.AutoMetricsClose
      ~Options.AutoMetricsLeft
      ~Options.AutoMetricsRight
      ~Options.AutoRemoveHints
      ~Options.AutoSave
      ~Options.AutoSaveTick
      ~Options.AutohintingHRatio
      ~Options.AutohintingMaxHWidth
      ~Options.AutohintingMaxVWidth
      ~Options.AutohintingMinHLen
      ~Options.AutohintingMinHWidth
      ~Options.AutohintingMinVLen
      ~Options.AutohintingMinVWidth
      ~Options.AutohintingRemoveHints
      ~Options.AutohintingVRatio
      ~Options.Backup
      ~Options.BitmapSize
      ~Options.CacheTTPath
      ~Options.CacheTTUse
      ~Options.ChartApplyTemplate
      ~Options.ChartAutoHide
      ~Options.ChartAutoUnicode
      ~Options.ChartCaptionFontCharSet
      ~Options.ChartCaptionFontName
      ~Options.ChartCaptionFontSize
      ~Options.ChartDoubleClick
      ~Options.ChartDragDrop
      ~Options.ChartPreviewMarks
      ~Options.ChartSampleSize
      ~Options.ChartShowNotes
      ~Options.ChartSorting
      ~Options.ChartStyle
      ~Options.ChartTemplateFontCharSet
      ~Options.ChartTemplateFontName
      ~Options.ChartTemplateFontSize
      ~Options.ChartUseTemplate
      ~Options.ClosepathArrowLen
      ~Options.CodepagesCount
      ~Options.ColorBitmap
      ~Options.ColorClosepath
      ~Options.ColorEcho
      ~Options.ColorHintsPen
      ~Options.ColorMaskPen
      ~Options.ColorSeacPen
      ~Options.ColorTemplate
      ~Options.ColorVMetrics
      ~Options.ContourSnapAllPoints
      ~Options.CopyHDMXData
      ~Options.CreateUnexistingCharacters
      ~Options.DefaultGlyph
      ~Options.DuplicateX
      ~Options.DuplicateY
      ~Options.EditBCPsFixed
      ~Options.EditBitmapStyle
      ~Options.EditChangeCursor
      ~Options.EditDeleteAlt
      ~Options.EditDoubleClickBitmap
      ~Options.EditEditSelection
      ~Options.EditFollowScroll
      ~Options.EditGridX
      ~Options.EditGridY
      ~Options.EditHandleTool
      ~Options.EditHitDistance
      ~Options.EditInstantRefresh
      ~Options.EditLeaveEcho
      ~Options.EditNoToolbars
      ~Options.EditNotFillOpen
      ~Options.EditRulers
      ~Options.EditScaleEPS
      ~Options.EditShowCross
      ~Options.EditShowPosition
      ~Options.EditShowSelection
      ~Options.EditSmallNodes
      ~Options.EditSmoothOutline
      ~Options.EraseSize
      ~Options.FitAscender
      ~Options.FitDescender
      ~Options.FontAudit
      ~Options.GlyphsBarOpen
      ~Options.HideAllLayers
      ~Options.HideToolbars
      ~Options.LockStyleEx
      ~Options.NamesFileName
      ~Options.OTAddClasses
      ~Options.OTReadMort
      ~Options.OTWriteGDEF
      ~Options.OTWriteMort
      ~Options.OptimizeAlign
      ~Options.OptimizeReduce
      ~Options.OverlapMode
      ~Options.PaintAutoTransform
      ~Options.PaintAutoView
      ~Options.PaintBrushBody
      ~Options.PaintBrushCap
      ~Options.PaintBrushJoin
      ~Options.PaintBrushRoundness
      ~Options.PaintBrushVectorX
      ~Options.PaintBrushVectorY
      ~Options.PaintBrushWidth
      ~Options.PaintColor
      ~Options.PaintMode
      ~Options.PaintStyleEx
      ~Options.PaintTextSize
      ~Options.PaintTool
      ~Options.PaintTracePolygon
      ~Options.PasteX
      ~Options.PasteY
      ~Options.PreviewExpanded
      ~Options.PreviewExpandedHeight
      ~Options.PreviewPPMs
      ~Options.PreviewPPMsExpanded
      ~Options.PreviewPointSize
      ~Options.PreviewSecondLine
      ~Options.PreviewSmooth
      ~Options.PreviewWidth
      ~Options.SamplePPM1
      ~Options.SamplePPM2
      ~Options.ShowMeterPanel
      ~Options.SnapStyleEx
      ~Options.T1AFM
      ~Options.T1Autohint
      ~Options.T1Decompose
      ~Options.T1Encoding
      ~Options.T1PFM
      ~Options.T1Terminal
      ~Options.T1Unicode
      ~Options.T1UseOS2
      ~Options.TTEAddCharacters
      ~Options.TTEApplyBBoxSavings
      ~Options.TTEAutoWinAscDesc
      ~Options.TTEAutohint
      ~Options.TTECmap10
      ~Options.TTEExportOT
      ~Options.TTEExportUnicode
      ~Options.TTEExportVOLT
      ~Options.TTEFontNames
      ~Options.TTEHint
      ~Options.TTEKeep
      ~Options.TTENoReorder
      ~Options.TTESubrize
      ~Options.TTEVisual
      ~Options.TTEWriteBitmaps
      ~Options.TTEWriteKernFeature
      ~Options.TTEheadBBoxSavings
      ~Options.TTHHintingOptions
      ~Options.TTIAutohint
      ~Options.TTIConvert
      ~Options.TTIDecompose
      ~Options.TTIFontNames
      ~Options.TTIKeepHints
      ~Options.TTIReadBitmaps
      ~Options.TTIReadKernFeature
      ~Options.TTIReadOT
      ~Options.TTIScale1000
      ~Options.TTIStoreTables
      ~Options.TTToolReverseShift
      ~Options.TracerCurveFit
      ~Options.TracerCurves
      ~Options.TracerExtremePoints
      ~Options.TracerPresetMode
      ~Options.TracerStraightenAngle
      ~Options.TracerTolerance
      ~Options.TrackingDistance
      ~Options.TrackingMode
      ~Options.UnicodeRangePercent
      ~Options.UnicodeStrings
      ~Options.VendorCode
   
   